@@ -1,11 +1,11 @@
 import importlib.metadata
 import logging
 from pathlib import Path
-from typing import Dict, Any, Callable, Type, Union
+from typing import Dict, Callable, Type, Union, TypeVar
 
 __version__ = importlib.metadata.version(__package__ or __name__)
 
-logging.basicConfig(format='%(asctime)d-%(levelname)s-%(message)s')
+logging.basicConfig(format='%(asctime)s-%(levelname)s-%(message)s', level=logging.DEBUG)
 
 # folders location
 
@@ -15,5 +15,7 @@ FOLDER_ROOT = FOLDER_SOURCE.parent
 FOLDER_DATA = Path(FOLDER_ROOT, 'data')
 
 # custom type hints
-JsonLike = Union[Dict[str, Any], Any]
+T = TypeVar('T')
+
+JsonLike = Union[Dict[str, T], T]
 TypeLike = Union[Callable, Type]
